%% ################################################### %%
%       Kinematics calculations, Raptor manipulator     %
%            Denavit-Hartenberg Representation          %
%                                                       %
%                 Christian Heimdal Sunde               %
%                    Master thesis 2014                 %
%  ###################################################  %

%% Define symbols


% Angles

syms    Th1     Th2     Th3     Th4     Th5     Th6
syms    alph1    alph2   alph3   alph4   alph5   alph6

% Distances

syms    a1      a2      a3      a4      a5      a6
syms    d1      d2      d3      d4      d5      d6

% Pi

pi = sym('pi');

% Some known values

        alph1 = 90; d1 = 0;
        alph2 = 0;  d2 = 0;
        alph3 = 90; d3 = 0;
        alph4 = 90; d4 = 0;
a5 = 0; alph5 = -90;d5 = 0;
a6 = 0; alph6 = 0;

% Simplify into matrices

Theta   =   [Th1    Th2     Th3     Th4     Th5     Th6  ];
alpha   =   [alph1  alph2   alph3   alph4   alph5   alph6]*pi/180;
a       =   [a1     a2      a3      a4      a5      a6   ];
d       =   [d1     d2      d3      d4      d5      d6   ];

%% Denavit-Hartenberg matrices

A = cell(1,length(a));

for i = 1:length(a)
    A{i} = [cos(Theta(i))   -sin(Theta(i))*cos(alpha(i))    sin(Theta(i))*sin(alpha(i))     a(i)*cos(Theta(i))  ;...
            sin(Theta(i))   cos(Theta(i))*cos(alpha(i))     -cos(Theta(i))*sin(alpha(i))    a(i)*sin(Theta(i))  ;...
            0               sin(alpha(i))                   cos(alpha(i))                   d(i)                ;...
            0               0                               0                               1                  ];
    str = sprintf('A_%d =',i);
    disp(str)
    disp(A{i})
end
    

%% Transformation matrix 

T = cell(1,length(a));
T{1} = 1;

for i = 1:length(a)
    T{i+1}=T{i}*A{i};
    str = sprintf('T_0^%d =',i);
    disp(str)
    disp(T{i+1})
end
